#
# spec file for package adaptx
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           adaptx
Version:        0.9.13
Release:        137.2
Summary:        XSLT Processor Written in Java
License:        BSD-3-Clause
Group:          Development/Libraries/Java
URL:            http://castor.exolab.org/
Source0:        %{name}-%{version}-src.tar.bz2
# svn export http://svn.codehaus.org/castor/adaptx
Patch0:         %{name}-%{version}-xsl.patch
Patch1:         %{name}-%{version}-icedtea-build.patch
BuildRequires:  ant >= 1.6
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-tools
BuildRequires:  reload4j
BuildRequires:  xerces-j2
BuildRequires:  xml-apis
Requires:       reload4j
Requires:       xerces-j2
Requires:       xml-apis
BuildArch:      noarch

%description
AdaptX is an extensible stylesheet language (XSL) processor.

%package javadoc
Summary:        Javadoc for adaptx
Group:          Development/Libraries/Java

%description javadoc
This package contains the javadoc documentation for AdaptX.

%package doc
Summary:        Documentation for adaptx
Group:          Development/Libraries/Java

%description doc
This package contains the documentation for AdaptX.

%prep
%setup -q -n %{name}-%{version}-src
# remove CVS internal files
for dir in `find . -type d -name CVS`; do rm -rf $dir; done
# remove all binary libs
for j in $(find . -name "*.jar"); do
	mv $j $j.no
done
%patch -P 0
%patch -P 1

%build
perl -p -i -e 's|classic|modern|' src/build.xml
export CLASSPATH=$(build-classpath xml-apis reload4j xerces-j2)
ant -Dant.build.javac.source=8 -Dant.build.javac.target=8 -buildfile src/build.xml jar javadoc
CLASSPATH=$CLASSPATH:dist/adaptx_%{version}.jar
ant -Dant.build.javac.source=8 -Dant.build.javac.target=8 -buildfile src/build.xml doc

%install
# jar
install -d -m 755 %{buildroot}%{_javadir}
install -m 644 dist/%{name}_%{version}.jar %{buildroot}%{_javadir}/%{name}-%{version}.jar
(cd %{buildroot}%{_javadir} && for jar in *-%{version}.jar; do ln -sf ${jar} ${jar/-%{version}/}; done)
# javadoc
install -d -m 755 %{buildroot}%{_javadocdir}/%{name}
cp -pr build/doc/javadoc/* %{buildroot}%{_javadocdir}/%{name}
rm -rf build/doc/javadoc

%files
%defattr(0664,root,root,0755)
%doc src%{_sysconfdir}/{CHANGELOG,contributors.html,LICENSE}
%{_javadir}/*

%files javadoc
%defattr(0664,root,root,0755)
%{_javadocdir}/%{name}

%files doc
%defattr(0664,root,root,0755)
%doc build/doc/*

%changelog
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Tue Feb 22 2022 Fridrich Strba <fstrba@suse.com>
- Do not build against the log4j12 packages, use the new reload4j
* Tue Oct  1 2019 Fridrich Strba <fstrba@suse.com>
- Build against the new compatibility log4j12-mini package
* Thu Dec  6 2018 Fridrich Strba <fstrba@suse.com>
- Don't require the removed xerces-j2-xml-apis, build against a
  generic xml-apis provider in order to allow bootstrapping
* Tue May 15 2018 fstrba@suse.com
- Build with source and target 8 to prepare for a possible removal
  of 1.6 compatibility
* Thu Sep 14 2017 fstrba@suse.com
- Fix building with jdk9 by specifying java source and target 1.6
* Fri May 19 2017 tchvatal@suse.com
- Do not require the builddeps, only the tools we really use
* Thu Dec  4 2014 p.drouand@gmail.com
- Drop java-devel dependency; replaced with javapackages-tools
* Fri Jul 11 2014 tchvatal@suse.com
- Do not version java docdir.
* Mon Jul  7 2014 tchvatal@suse.com
- Remove some redundant definitions from spec
* Mon Jul  7 2014 tchvatal@suse.com
- Cleanup with spec-cleaner and fix build with xerces-j2-xml-apis
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Thu Feb 28 2008 mvyskocil@suse.cz
- Adopted from jpackage(1.7)
- New version 0.9.13
  - Fixed bug where normalize-space() function required an argument.
    With no arguments, it now correctly defaults to the context node.
    (kvisco - 20050114)
  - Backed out previous fix in 0.9.12. It was an incorrect fix,
    there was actually no bug with the node-set comparisons
    after triple-checking the XPath spec. When comparing two nodesets
    sometimes they can both be equal and not-equal at the same time,
    and sometimes they can both be never and equal, and never not-equal.
    It's very confusing, but the previous implementation had it correct.
  - Fixed bug in EqualyExprImpl with respect to the NOT_EQUALS
    operator (!=) when used with NodeSet comparisons.
  - Fixed issue with xsl:sort that was restricting the result of
    the expression specified by the select attribute to be a
    node-set, instead of any valid XPath result.
  - Fixed some NullPointerExceptions that were occurring when
    attempting to create a StringResult with a null value.
  - Fixed issue of possible incorrect context node
    when processing certain expressions at the top-level.
  - Fixed parse error when using variables in union expressions.
  - Fixed issue with using the node-test keywords in
    attribute expressions (eg: @text, @node, @pi)
  - Added some improvements to the expressions API to
    allow greater ability to "drill-down" and get to
    the core components of the XPath expressions.
  - Fixes issue with error occuring when "xml prefix" is being
    declared by Xerces. Normally, the "xml" prefix shouldn't
    be declared, but Xerces declares this, probably as a
    convenience. The error is changed to check only for
    a redefinition of the "xml" prefix to a non-valid
    URI.
  - Made some improvements to the XPath expressions package to
    allow improved accessibility to the components of a given
    expression. Improvements include the ability to obtain the
    Operator type of a BinaryExpr and a new GroupedExpression
    interface for expressions wrapped in parenthesis.
    (kvisco - 2003-10-06)
  - Added Identity transformation support in the JAXP implementation
    (kvisco - 2003-10-06)
  - Fixed *static* variable bug in the Lexer, should fix some problems
    with certain operators being treated as a function name. This was
    a regression from 0.9.5 (I think).
    (kvisco - 2003-10-02)
  - Added support for URIResolver in the JAXP implementation
    (kvisco - 2003-10-01)
  - Fixed document-base bug with document() function
    (kvisco - 2003-09-28)
  - Updated to support JAXP. The user must first configure
    their environment by setting within the system properties
    the JAXP property: javax.xml.transform.TransformerFactory
    to the value of:
    org.exolab.adaptx.jaxp.transform.TransformerFactoryImpl
    (kvisco - 2003-09-09)
- Compiled by icedtea
* Fri Sep 15 2006 ro@suse.de
- set source=1.4 for java
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jul 27 2005 jsmeix@suse.de
- Adjustments in the spec file.
* Mon Jul 18 2005 jsmeix@suse.de
- Current version 0.9.6 from JPackage.org
* Thu Sep 16 2004 skh@suse.de
- Fix prerequires of javadoc subpackage
* Sun Sep  5 2004 skh@suse.de
- Initial package created with version 0.9.6 (JPackage 1.5)
